//+------------------------------------------------------------------+
//|                            ScriptToExportClosedTrades+Prompt.mq4 |
//+------------------------------------------------------------------+
#property copyright "Copyright - Interbank FX, LLC."
#property link      "http://www.ibfx.com"

#import "shell32.dll"
int ShellExecuteA(int h,string lpOp, string lpFile,string lpParameters,string lpDirectory,int nShowCmd );

//+------------------------------------------------------------------+
//|      					  MessageBox Codes						 |
//+------------------------------------------------------------------+
#define IDYES                          6
#define IDNO                           7
#define MB_OK                       	0x00000000
#define MB_YESNO                    	0x00000004
#define MB_ICONQUESTION             	0x00000020
#define MB_ICONEXCLAMATION          	0x00000030
#define SW_SHOWNORMAL 1
//+------------------------------------------------------------------+

//+------------------------------------------------------------------+
//| script program start function                                    |
//+------------------------------------------------------------------+
int start()
{
/*
Because we are using a dll here we need to make sure the user has
allowed the use of dll's before doing anything else!!!
*/
if( !IsDllsAllowed() )
{
int ret = MessageBox( "DLL Calls are not allowed. Please click on Tools \ Options \ Expert Advisor and select \"Allow DLL Imports\"",
"Message Box Title Here!",
MB_OK|MB_ICONEXCLAMATION
);
return(0);
}

/*
If I wanted to export current live trades to a csv file I would
first have to open a file then go through the orders data and write
the data I needed then close the file.

So in essence my algorithm would be:

OpenFile()
Loop through orders()
->write data()
CloseFile()
Prompt to open created file

*/
//---- Let's create a variable for our file name:
string FileName = "MyClosedTrades.csv";
// MyClosedTrades.xls
// MyClosedTrades.txt
// Note here that you can use any file type you want.

//---- Open File
int FileHandle = OpenFile( FileName );

//---- Did the file open successully?
if( FileHandle > 0 )
{
LoopThroughLiveOrders( FileHandle );
LoopThroughClosedOrders( FileHandle );
}
else
{
Print( StringConcatenate( FileName," - File Not Found! Error# ", GetLastError() ) );
return(0);
}

//---- Close the file
CloseFile( FileHandle );

//---- Do you want to open the file?
int Prompt = MessageBox( "File was created. Would you like to open it?", "Message Box Title Here!", MB_YESNO|MB_ICONQUESTION );
if( Prompt == IDYES )
{
string PAT = TerminalPath();
string URL = StringConcatenate( PAT,"\experts\files/", FileName);
ShellExecuteA(0, "open", URL, NULL, NULL, 0);
}

//---- We're done!
return(0);
}
//+------------------------------------------------------------------+

//+------------------------------------------------------------------+
//| OpenFile                                                         |
//+------------------------------------------------------------------+
int OpenFile( string sFileName )
{
int H = 0;
//---- For an csv file I would use:
H = FileOpen( sFileName, FILE_CSV|FILE_WRITE, ',' );
//---- For a xls or txt file I would use
// H = FileOpen( sFileName, FILE_CSV|FILE_WRITE, '\t' );

//---- If file opened or was created successfully
if( H > 0 )
{
// Let's create a header
FileWrite( H, "OrderTicket", "Symbol", "OrderType", "OpenPrice" );
}
//----
return(H);
}
//+------------------------------------------------------------------+

//+------------------------------------------------------------------+
//| LoopThroughLiveOrders                                            |
//+------------------------------------------------------------------+
void LoopThroughLiveOrders( int FileHandle )
{
int TotalOrders = OrdersTotal();
if( TotalOrders <= 0 )
{
FileWrite( FileHandle, "No Live orders Found" );
}
else
{
FileWrite( FileHandle, "\nOPENED ORDERS" );
for( int i = TotalOrders-1; i >= 0; i-- )
{
if( OrderSelect(i,SELECT_BY_POS,MODE_TRADES) == false ) { continue; }

string Ticket = OrderTicket();
string    Sym = StringSubstr( OrderSymbol(), 0, 6 );
string   Type = "";
string  Entry = DoubleToStr( OrderOpenPrice(), Digits );

//---- Order Type Switch
switch( OrderType() )
{
case        OP_BUY: Type = "MARKET BUY";          break;
case       OP_SELL: Type = "MARKET SELL";         break;
case   OP_BUYLIMIT: Type = "LIMIT BUY";           break;
case  OP_SELLLIMIT: Type = "LIMIT SELL";          break;
case    OP_BUYSTOP: Type = "STOP BUY";            break;
case   OP_SELLSTOP: Type = "STOP SELL";           break;
case             6: Type = "Deposit/Withdrawal";  Entry = DoubleToStr( OrderProfit() ,2);
break;
default: Type = " Unknown Order Type";
break;
}
FileWrite( FileHandle, Ticket, Sym, Type, Entry );
//----
}
}
//----
return;
}
//+------------------------------------------------------------------+

//+------------------------------------------------------------------+
//| LoopThroughClosedOrders                                          |
//+------------------------------------------------------------------+
void LoopThroughClosedOrders( int FileHandle )
{
int TotalOrders = OrdersHistoryTotal();
if( TotalOrders <= 0 )
{
FileWrite( FileHandle, "No Live orders Found" );
}
else
{
FileWrite( FileHandle, "\nCLOSED ORDERS" );
for( int i = TotalOrders-1; i >= 0; i-- )
{
if( OrderSelect(i,SELECT_BY_POS,MODE_HISTORY ) == false ) { continue; }

string Ticket = OrderTicket();
string    Sym = StringSubstr( OrderSymbol(), 0, 6 );
string   Type = "";
string  Entry = DoubleToStr( OrderOpenPrice(), Digits );

//---- Order Type Switch
switch( OrderType() )
{
case        OP_BUY: Type = "MARKET BUY";          break;
case       OP_SELL: Type = "MARKET SELL";         break;
case   OP_BUYLIMIT: Type = "LIMIT BUY";           break;
case  OP_SELLLIMIT: Type = "LIMIT SELL";          break;
case    OP_BUYSTOP: Type = "STOP BUY";            break;
case   OP_SELLSTOP: Type = "STOP SELL";           break;
case             6: Type = "Deposit/Withdrawal";  Entry = DoubleToStr( OrderProfit() ,2);
break;
default: Type = " Unknown Order Type";
break;
}
FileWrite( FileHandle, Ticket, Sym, Type, Entry );
//----
}
}
//----
return;
}
//+------------------------------------------------------------------+

//+------------------------------------------------------------------+
//| CloseFile                                                        |
//+------------------------------------------------------------------+
void CloseFile( int Handle )
{
if( Handle > 0 )
{ FileClose(Handle); }
Handle = 0;
}
//+------------------------------------------------------------------+
