//+------------------------------------------------------------------+
//|                                     ScriptToExportLiveTrades.mq4 |
//+------------------------------------------------------------------+
#property copyright "Copyright - Interbank FX, LLC."
#property link      "http://www.ibfx.com"
//+------------------------------------------------------------------+
//| script program start function                                    |
//+------------------------------------------------------------------+
int start()
{
/*
If I wanted to export current live trades to a csv file I would
first have to open a file then go through the orders data and write
the data I needed then close the file.

So in essence my algorithm would be:

OpenFile()
Loop through orders()
->write data()
CloseFile()
*/
//---- Let's create a variable for our file name:
string FileName = "MyLiveTrades.csv";
// MyLiveTrades.xls
// MyLiveTrades.txt
// Note here that you can use any file type you want.

//---- Open File
int FileHandle = OpenFile( FileName );

//---- Did the file open successully?
if( FileHandle > 0 )
{
LoopThroughLiveOrders( FileHandle );
}
else
{
Print( StringConcatenate( FileName," - File Not Found! Error# ", GetLastError() ) );
return(0);
}

//---- Close the file
CloseFile( FileHandle );

//---- We're done!
return(0);
}
//+------------------------------------------------------------------+

//+------------------------------------------------------------------+
//| OpenFile                                                         |
//+------------------------------------------------------------------+
int OpenFile( string sFileName )
{
int H = 0;
//---- For an xls file I would use:
H = FileOpen( sFileName, FILE_CSV|FILE_WRITE, ',' );
//---- For a csv or txt file I would use
// H = FileOpen( sFileName, FILE_CSV|FILE_WRITE, ',' );

//---- If file opened or was created successfully
if( H > 0 )
{
// Let's create a header
FileWrite( H, "OrderTicket", "Symbol", "OrderType", "OpenPrice" );
}
//----
return(H);
}
//+------------------------------------------------------------------+

//+------------------------------------------------------------------+
//| LoopThroughLiveOrders                                            |
//+------------------------------------------------------------------+
void LoopThroughLiveOrders( int FileHandle )
{
int TotalOrders = OrdersTotal();
if( TotalOrders <= 0 )
{
FileWrite( FileHandle, "No Live orders Found" );
}
else
{
for( int i = TotalOrders-1; i >= 0; i-- )
{
if( OrderSelect(i,SELECT_BY_POS,MODE_TRADES) == false ) { continue; }

string Ticket = OrderTicket();
string    Sym = StringSubstr( OrderSymbol(), 0, 6 );
string   Type = "";
string  Entry = DoubleToStr( OrderOpenPrice(), Digits );

//---- Order Type Switch
switch( OrderType() )
{
case        OP_BUY: Type = "MARKET BUY";          break;
case       OP_SELL: Type = "MARKET SELL";         break;
case   OP_BUYLIMIT: Type = "LIMIT BUY";           break;
case  OP_SELLLIMIT: Type = "LIMIT SELL";          break;
case    OP_BUYSTOP: Type = "STOP BUY";            break;
case   OP_SELLSTOP: Type = "STOP SELL";           break;
case             6: Type = "Deposit/Withdrawal";  Entry = DoubleToStr( OrderProfit() ,2);
break;
default: Type = " Unknown Order Type";
break;
}
FileWrite( FileHandle, Ticket, Sym, Type, Entry );
//----
}
}
//----
return;
}
//+------------------------------------------------------------------+

//+------------------------------------------------------------------+
//| CloseFile                                                        |
//+------------------------------------------------------------------+
void CloseFile( int Handle )
{
if( Handle > 0 )
{ FileClose(Handle); }
Handle = 0;
}
//+------------------------------------------------------------------+
